Coding Style Test
=================

Test for a few parts of the coding style.
For example options should be passed as non-const value for small datatypes (`int`,`char`,`BoutReal`,...)

```C++
void fu(int a);
```